==> nextcloud-app-bookmarks-1%3A4.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/sl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Zaznamki",
    "You bookmarked \"%s\"" : "Ustvarite zaznamek »%s«",
    "%1$s bookmarked \"%2$s\"" : "%1$s ustvari zaznamek »%2$s«",
    "Someone bookmarked \"%s\"" : "Nekdo ustvari zaznamek »%s«",
    "You deleted \"%s\"" : "Izbrišete »%s«",
    "%1$s deleted \"%2$s\"" : "%1$s izbriše »%2$s«",
    "Someone deleted \"%s\"" : "Nekdo izbriše »%s«",
    "You created folder \"%s\"" : "Ustvarite mapo »%s«",
    "%1$s created folder \"%2$s\"" : "%1$s ustvari mapo »%2$s«",
    "Someone created folder \"%s\"" : "Nekdo ustvari mapo »%s«",
    "You moved folder \"%s\"" : "Premaknete mapo »%s«",
    "%1$s moved folder \"%2$s\"" : "%1$s premakne mapo »%2$s«",
    "Someone moved folder \"%s\"" : "Nekdo premakne mapo »%s«",
    "You deleted folder \"%s\"" : "Izbrišete mapo »%s«",
    "%1$s deleted folder \"%2$s\"" : "%1$s izbriše mapo »%2$s«",
    "Someone deleted folder \"%s\"" : "Nekdo izbriše mapo »%s«",
    "You shared folder \"%s\" with someone" : "Omogočite souporabo mape »%s«",
    "%1$s shared folder \"%2$s\" with you" : "%1$s vam omogoči souporabo mape »%2$s«",
    "Someone shared folder \"%s\" with you" : "Nekdo vam omogoči souporabo mape »%s«",
    "You unshared folder \"%1$s\" with %2$s" : "Prekinili ste souporabo mape \"%1$s\" z \"%2$s\"",
    "You unshared folder \"%s\" with someone" : "Z nekom ste prekinili deljenje mape \"%s\"",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s vam onemogoči souporabo mape »%2$s«",
    "Someone unshared folder \"%s\" with you" : "Nekdo vam onemogoči souporabo mape »%s«",
    "No file provided for import" : "Ni navedenih datotek za uvoz",
    "Unsupported file type for import" : "Nepodprta vrsta datoteke za uvoz",
    "Bookmarks shared by %s" : "Zaznamki v souporabi z %s",
    "Recent Bookmarks" : "Nedavni zaznamki",
    "Bookmark" : "Zaznamek",
    "Bookmark deleted" : "Zaznamek je izbrisan",
    "Bookmark created" : "Zaznamek je ustvarjen",
    "Bookmark moved" : "Zaznamek je premaknjen",
    "Bookmark updated" : "Zaznamek je posodobljen",
    "Create bookmark" : "Ustvari zaznamek",
    "Takes a link and adds it to your collection of bookmarks." : "Prevzame povezavo in jo doda v zbirko zaznamkov.",
    "A Bookmark manager for Nextcloud" : "Upravljalnik zaznamkov za Nextcloud",
    "This app provides you with a web interface for collecting, organizing and sharing bookmarks to the sites on the web that are precious to you.\nYou can browse and filter your bookmarks via tags, folders and by using the built-in search feature and you can share folders with other users and groups as well as create public links for them.\nAlso, in order to access your bookmarks anywhere, it also allows you to synchronize with third-party clients via a built-in REST API -- be it in your browsers or on your phone.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients\n\nRequirements:\n - PHP v7.3+\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - Nextcloud v20+" : "Program omogoča uporabo spletnega vmesnika za zbiranje in urejanje zaznamkov do spletnih strani.\nTe je mogoče prebrskati, filtrirati prek oznak, označevati in urejati v mape, mogoče pa jih je tudi iskati po ključnih besedah in omogočati za neposredno souporabo ali souporabo prek povezave.\nZa dostop do njih kjerkoli in kadarkoli, program omogoča tudi usklajevanje z različnimi odjemalci prek vmesnika REST API v brskalniku, ali na pametni napravi.\nSeznam različnih odjemalcev je na voljo na https://github.com/nextcloud/bookmarks#third-party-clients\n\nProgramske zahteve:\n- PHP različice 7.3+ ali višje\n- Razširitve PHP:\n  - intl: *\n  - mbstring: *\n- Nextcloud različice 20 ali višje",
    "Enter new title" : "Vpis novega naslova",
    "Select bookmark" : "Izbor zaznamka",
    "Details" : "Podrobnosti",
    "Rename" : "Preimenuj",
    "Move" : "Premakni",
    "Delete" : "Izbriši",
    "Search" : "Poišči",
    "Select one or more tags" : "Izbor enega oziroma več zaznamkov",
    "New" : "Novo",
    "New bookmark" : "Nov zaznamek",
    "New folder" : "Nova mapa",
    "Grid view" : "Mrežni pogled",
    "List view" : "Seznamski pogled",
    "Move selection" : "Premakni izbor",
    "Delete selection" : "Izbriši izbor",
    "Open all selected" : "Odpri vse izbrane",
    "Select all" : "Izberi vse",
    "Cancel selection" : "Prekliči izbor",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Izbrane mape {folders} in zaznamki {bookmarks}",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Izbran je %n zaznamek","Izbrana sta %n zaznamka","Izbrani so %n zaznamki","Izbranih je %n zaznamkov"],
    "_Selected %n folder_::_Selected %n folders_" : ["Izbrana je %n mapa","Izbrani sta %n mapi","Izbrane so %n mape","Izbranih je %n map"],
    "Enter a link" : "Vnesite povezavo",
    "Enter a title" : "Vpis naslova",
    "No bookmarks found" : "Ni najdenih zaznamkov",
    "Select folder" : "Izbor mape",
    "Enter folder title" : "Vnesite naziv mape",
    "Shared by {user}" : "V skupni rabi z {user}",
    "Root folder" : "Korenska mapa",
    "Submit" : "Pošlji",
    "Cancel" : "Prekliči",
    "Deleting bookmarks" : "Brisanje zaznamkov",
    "Deleting selection" : "Brisanje izbora",
    "Importing bookmarks" : "Uvažanje zaznamkov",
    "Moving selection" : "Premikanje izbora",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Premikanje mape %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov"],
    "_Moving %n folder_::_Moving %n folders_" : ["Poteka premikanje %n mape","Poteka premikanje %n map","Poteka premikanje %n map","Poteka premikanje %n map"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Poteka premikanje %n zaznamka","Poteka premikanje %n zaznamkov","Poteka premikanje %n zaznamkov","Poteka premikanje %n zaznamkov"],
    "All bookmarks" : "Vsi zaznamki",
    "Recent" : "Nedavne",
    "Archived" : "Arhivirano",
    "Broken links" : "Okvarjene povezave",
    "Filter tags" : "Filtriraj oznake",
    "Untagged" : "Neoznačeno",
    "{used} bookmarks of {available} available" : "zaznamkov {used} od razpoložljivih {available}",
    "No archived bookmarks" : "Ni arhiviranih zaznamkov",
    "No bookmarks here" : "Ni še dodanih zaznamkov.",
    "Add a bookmark" : "Dodaj zaznamek",
    "Import bookmarks" : "Uvozi zaznamke",
    "Import" : "Uvozi",
    "Export" : "Izvozi",
    "Sorting" : "Razvrščanje",
    "Recently added" : "Nedavno dodano",
    "Alphabetically" : "Abecedno",
    "Most visited" : "Najpogosteje obiskano",
    "Last modified" : "Nazadnje spremenjeno",
    "Custom order" : "Razporeditev po meri",
    "Archive path" : "Arhiviraj pot",
    "Enter the path of a folder where bookmarked files should be stored" : "Vpis poti do mape, kjer bi morali biti shranjeni zaznamki datotek",
    "Client apps" : "Odjemalski programi",
    "Install web app" : "Namesti spletni program",
    "Install on home screen" : "Namesti na začetni zaslon",
    "Bookmarklet" : "Program za zaznamke",
    "Add to {instanceName}" : "Dodaj {instanceName} ",
    "Clear data" : "Počisti podatke",
    "Delete all bookmarks" : "Izbriši vse zaznamke",
    "Do you really want to delete all your bookmarks?" : "Ali res želite izbrisati vse zaznamke?",
    "Title" : "Naslov",
    "Link" : "Povezava",
    "Creation date" : "Datum ustvarjanja",
    "Tags" : "Oznake",
    "Select tags and create new ones" : "Izberi oznake in ustvari nove",
    "Attachments" : "Priloge",
    "Archived version" : "Arhivirana različica",
    "Open archived file" : "Odpri arhivirano datoteko",
    "Notes" : "Opombe",
    "Notes for this bookmark …" : "Opombe za zaznamek ...",
    "{time} ago" : "pred {time}",
    "Owner" : "Lastnik",
    "Sharing" : "Souporaba",
    "Select a user or group" : "Izbor imena uporabnika oziroma skupine",
    "Share link" : "Povezava za souporabo",
    "Copy link" : "Kopiraj povezavo",
    "Copy RSS feed" : "Kopiraj vir RSS",
    "Delete link" : "Izbriši povezavo",
    "Create public link" : "Ustvari javno povezavo",
    "Allow editing" : "Dovoli urejanje",
    "Allow sharing" : "Dovoli omogočanje souporabe",
    "Remove share" : "Odstrani souporabo",
    "Link copied" : "Povezava je kopirana",
    "RSS feed copied" : "Vir RSS je kopiran",
    "Select" : "Izbor",
    "Previews" : "Predogledi",
    "Screeenly" : "Screeenly",
    "Screeenly API URL" : "Naslov URL vmesnika Screeenly API",
    "Screeenly API key" : "Ključ vmesnika Screeenly API",
    "Webshot" : "Slika spletne strani",
    "Webshot API URL" : "Slika spletne strani API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API ključ",
    "Pageres CLI" : "Pozivnik CLI",
    "Privacy" : "Zasebnost",
    "Performance" : "Delovanje",
    "Failed to load settings" : "Nalaganje nastavitev je spodletelo.",
    "Failed to save settings" : "Shranjevanje nastavitev je spodletelo",
    "This URL is already bookmarked! Overwrite?" : "Ta naslov URL je že dodan med zaznamke. Ali ga želite prepisati?",
    "Enter bookmark title" : "Naslov zaznamka",
    "Enter bookmark URL" : "Naslov URL zaznamka",
    "Folder" : "Mapa",
    "Root Folder" : "Korenska mapa",
    "Save" : "Shrani",
    "Failed to load bookmark" : "Nalaganje zaznamka je spodletelo",
    "Failed to find existing bookmark" : "Dostop do obstoječega zaznamka je spodletel",
    "Failed to create bookmark" : "Ustvarjanje zaznamka je spodletelo",
    "Failed to save bookmark" : "Shranjevanje zaznamka je spodletelo",
    "Failed to move bookmark" : "Premikanje zaznamka je spodletelo",
    "Failed to delete bookmark" : "Brisanje zaznamka je spodletelo",
    "Failed to rename tag" : "Preimenovanje oznake je spodletelo",
    "Failed to load tags" : "Nalaganje oznak je spodletelo",
    "Failed to load folders" : "Nalaganje map je spodletelo",
    "Failed to delete folder" : "Brisanje mape je spodletelo",
    "Failed to create folder" : "Ustvarjanje mape je spodletelo",
    "Failed to fetch bookmarks." : "Pridobivanje zaznamkov je spodletelo",
    "Failed to change setting" : "Spreminjanje nastavitev je spodletelo",
    "Failed to load setting {key}" : "Nalaganje ključa nastavitve {key} je spodletelo",
    "Failed to update share {shareId}" : "Posodabljanje {shareId} je spodletelo",
    "Failed to delete share {shareId}" : "Brisanje {shareId} je spodletelo",
    "Bookmarks feed" : "Vir zaznamkov"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-app-bookmarks-1%3A4.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/sl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Zaznamki",
    "You bookmarked \"%s\"" : "Ustvarite zaznamek »%s«",
    "%1$s bookmarked \"%2$s\"" : "%1$s ustvari zaznamek »%2$s«",
    "Someone bookmarked \"%s\"" : "Nekdo ustvari zaznamek »%s«",
    "You deleted \"%s\"" : "Izbrišete »%s«",
    "%1$s deleted \"%2$s\"" : "%1$s izbriše »%2$s«",
    "Someone deleted \"%s\"" : "Nekdo izbriše »%s«",
    "You created folder \"%s\"" : "Ustvarite mapo »%s«",
    "%1$s created folder \"%2$s\"" : "%1$s ustvari mapo »%2$s«",
    "Someone created folder \"%s\"" : "Nekdo ustvari mapo »%s«",
    "You moved folder \"%s\"" : "Premaknete mapo »%s«",
    "%1$s moved folder \"%2$s\"" : "%1$s premakne mapo »%2$s«",
    "Someone moved folder \"%s\"" : "Nekdo premakne mapo »%s«",
    "You deleted folder \"%s\"" : "Izbrišete mapo »%s«",
    "%1$s deleted folder \"%2$s\"" : "%1$s izbriše mapo »%2$s«",
    "Someone deleted folder \"%s\"" : "Nekdo izbriše mapo »%s«",
    "You shared folder \"%1$s\" with %2$s" : "Omogočite souporabo mape »%1$s« z »%2$s«",
    "You shared folder \"%s\" with someone" : "Omogočite souporabo mape »%s«",
    "%1$s shared folder \"%2$s\" with you" : "%1$s vam omogoči souporabo mape »%2$s«",
    "Someone shared folder \"%s\" with you" : "Nekdo vam omogoči souporabo mape »%s«",
    "You unshared folder \"%1$s\" with %2$s" : "Prekinili ste souporabo mape »%1$s« z »%2$s«",
    "You unshared folder \"%s\" with someone" : "Z nekom ste prekinili souporabo mape »%s«",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s vam onemogoči souporabo mape »%2$s«",
    "Someone unshared folder \"%s\" with you" : "Nekdo vam onemogoči souporabo mape »%s«",
    "No file provided for import" : "Ni navedenih datotek za uvoz",
    "Unsupported file type for import" : "Nepodprta vrsta datoteke za uvoz",
    "Bookmarks shared by %s" : "Zaznamki v souporabi z %s",
    "Recent Bookmarks" : "Nedavni zaznamki",
    "Bookmark" : "Zaznamek",
    "Bookmark deleted" : "Zaznamek je izbrisan",
    "Bookmark created" : "Zaznamek je ustvarjen",
    "Bookmark moved" : "Zaznamek je premaknjen",
    "Bookmark updated" : "Zaznamek je posodobljen",
    "Create bookmark" : "Ustvari zaznamek",
    "Takes a link and adds it to your collection of bookmarks." : "Prevzame povezavo in jo doda v zbirko zaznamkov.",
    "A Bookmark manager for Nextcloud" : "Upravljalnik zaznamkov za Nextcloud",
    "Enter new title" : "Vpis novega naslova",
    "Select bookmark" : "Izbor zaznamka",
    "Details" : "Podrobnosti",
    "Rename" : "Preimenuj",
    "Move" : "Premakni",
    "Delete" : "Izbriši",
    "Do you really want to delete this bookmark?" : "Ali ste prepričani, da želite izbrisati ta zaznamek?",
    "Select one or more tags" : "Izbor enega oziroma več zaznamkov",
    "New" : "Novo",
    "New bookmark" : "Nov zaznamek",
    "New folder" : "Nova mapa",
    "Grid view" : "Mrežni pogled",
    "List view" : "Seznamski pogled",
    "RSS Feed of current view" : "Vir RSS trenutnega pogleda",
    "Move selection" : "Premakni izbor",
    "Delete selection" : "Izbriši izbor",
    "Open all selected" : "Odpri vse izbrane",
    "Select all" : "Izberi vse",
    "Cancel selection" : "Prekliči izbor",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Izbrane mape {folders} in zaznamki {bookmarks}",
    "Do you really want to delete these items?" : "Ali ste prepričani, da želite izbrisati te predmete?",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Izbran je %n zaznamek","Izbrana sta %n zaznamka","Izbrani so %n zaznamki","Izbranih je %n zaznamkov"],
    "_Selected %n folder_::_Selected %n folders_" : ["Izbrana je %n mapa","Izbrani sta %n mapi","Izbrane so %n mape","Izbranih je %n map"],
    "Enter a link" : "Vnesite povezavo",
    "Enter a title" : "Vpis naslova",
    "No bookmarks found" : "Ni najdenih zaznamkov",
    "Select folder" : "Izbor mape",
    "Enter folder title" : "Vnesite naziv mape",
    "Shared by {user}" : "V skupni rabi z {user}",
    "Do you really want to delete this folder?" : "Ali ste prepričani, da želite izbrisati to mapo?",
    "Root folder" : "Korenska mapa",
    "Submit" : "Pošlji",
    "Cancel" : "Prekliči",
    "Deleting bookmarks" : "Brisanje zaznamkov",
    "Deleting selection" : "Brisanje izbora",
    "Importing bookmarks" : "Uvažanje zaznamkov",
    "Moving selection" : "Premikanje izbora",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Premikanje mape %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov","Premikanje map %n in nekaterih zaznamkov"],
    "_Moving %n folder_::_Moving %n folders_" : ["Poteka premikanje %n mape","Poteka premikanje %n map","Poteka premikanje %n map","Poteka premikanje %n map"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Poteka premikanje %n zaznamka","Poteka premikanje %n zaznamkov","Poteka premikanje %n zaznamkov","Poteka premikanje %n zaznamkov"],
    "All bookmarks" : "Vsi zaznamki",
    "Recent" : "Nedavne",
    "Archived" : "Arhivirano",
    "Broken links" : "Okvarjene povezave",
    "Filter tags" : "Filtriraj oznake",
    "Untagged" : "Neoznačeno",
    "{used} bookmarks of {available} available" : "Uporabljeno {used} od razpoložljivih {available}",
    "No archived bookmarks" : "Ni arhiviranih zaznamkov",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Zaznamki do datotek, kot so slike in dokumenti PDF, bodo samodejno shranjeni med datoteke Nextcloud, zato je dostop mogoč tudi pri delu brez povezave.",
    "No bookmarks here" : "Ni še dodanih zaznamkov.",
    "Add a bookmark" : "Dodaj zaznamek",
    "Import bookmarks" : "Uvozi zaznamke",
    "Import" : "Uvozi",
    "Export" : "Izvozi",
    "Sorting" : "Razvrščanje",
    "Recently added" : "Nedavno dodano",
    "Alphabetically" : "Abecedno",
    "Most visited" : "Najpogosteje obiskano",
    "Last modified" : "Nazadnje spremenjeno",
    "Custom order" : "Razporeditev po meri",
    "Archive path" : "Arhiviraj pot",
    "Enter the path of a folder where bookmarked files should be stored" : "Vpis poti do mape, kjer bi morali biti shranjeni zaznamki datotek",
    "Client apps" : "Odjemalski programi",
    "Also check out the collection of client apps that integrate with this app: " : "Preverite tudi zbirko programov, ki se povezujejo z zmožnostmi:",
    "Install web app" : "Namesti spletni program",
    "Install on home screen" : "Namesti na začetni zaslon",
    "Bookmarklet" : "Program za zaznamke",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Potegnite to med zaznamke brskalnika in kliknite za hitro dodajanje zaznamka spletne strani.",
    "Add to {instanceName}" : "Dodaj {instanceName} ",
    "Clear data" : "Počisti podatke",
    "Permanently remove all bookmarks from your account." : "Trajno odstrani vse zaznamke, povezane z računom.",
    "Delete all bookmarks" : "Izbriši vse zaznamke",
    "Do you really want to delete all your bookmarks?" : "Ali res želite izbrisati vse zaznamke?",
    "Please select \"Add to home screen\" in your browser menu" : "V meniju brskalnika izberite možnost »Dodaj na začetni zaslon«",
    "Title" : "Naslov",
    "Link" : "Povezava",
    "Creation date" : "Datum ustvarjanja",
    "Tags" : "Oznake",
    "Select tags and create new ones" : "Izberi oznake in ustvari nove",
    "Attachments" : "Priloge",
    "Archived version" : "Arhivirana različica",
    "Open archived file" : "Odpri arhivirano datoteko",
    "Notes" : "Opombe",
    "Notes for this bookmark …" : "Opombe za zaznamek ...",
    "{time} ago" : "pred {time}",
    "Owner" : "Lastnik",
    "Sharing" : "Souporaba",
    "Select a user or group" : "Izbor imena uporabnika oziroma skupine",
    "Share link" : "Povezava za souporabo",
    "Copy link" : "Kopiraj povezavo",
    "Copy RSS feed" : "Kopiraj vir RSS",
    "Delete link" : "Izbriši povezavo",
    "Create public link" : "Ustvari javno povezavo",
    "Allow editing" : "Dovoli urejanje",
    "Allow sharing" : "Dovoli omogočanje souporabe",
    "Remove share" : "Odstrani souporabo",
    "Link copied" : "Povezava je kopirana",
    "RSS feed copied" : "Vir RSS je kopiran",
    "Select" : "Izbor",
    "Previews" : "Predogledi",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Za prikaz pravih zaslonskih slik zaznamkov spletnih strani, program uporablja storitve tretjih oseb za ustvarjanje predogledov.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Lahko se brezplačno vpišete na spletni strani screeenly.com, ali pa nastavite svoj strežnik.",
    "Screeenly API URL" : "Naslov URL vmesnika Screeenly API",
    "Screeenly API key" : "Ključ vmesnika Screeenly API",
    "Webshot" : "Slika spletne strani",
    "Webshot API URL" : "Slika spletne strani API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Ključ vmesnika API ScreenshotMachine",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "Enostavno namestite vmesnik pozivnika cli na strežnik in program bo sam našel povezavo.",
    "Privacy" : "Zasebnost",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Program poskuša pridobiti podatke dodanih spletnih strani in jih dodati v opis povezave.",
    "Enable accessing and collecting information from the web pages you add" : "Omogoči dostop in zbiranje podatkov z dodanih spletnih strani",
    "Performance" : "Delovanje",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Na sistemu z velikim številom uporabnikov je priporočeno omejiti število zaznamkov na račun",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Največje dovoljeno število zaznamkov na račun (privzeta vrednost je 0 – brez omejitve)",
    "Failed to load settings" : "Nalaganje nastavitev je spodletelo.",
    "Failed to save settings" : "Shranjevanje nastavitev je spodletelo",
    "This URL is already bookmarked! Overwrite?" : "Ta naslov URL je že dodan med zaznamke. Ali ga želite prepisati?",
    "Enter bookmark title" : "Naslov zaznamka",
    "Enter bookmark URL" : "Naslov URL zaznamka",
    "Folder" : "Mapa",
    "Root Folder" : "Korenska mapa",
    "Save" : "Shrani",
    "Failed to count unavailable bookmarks" : "Štetje nerazpoložljivih zaznamkov je spodletelo",
    "Failed to count archived bookmarks" : "Štetje arhiviranih zaznamkov je spodletelo",
    "Failed to load bookmark" : "Nalaganje zaznamka je spodletelo",
    "Failed to find existing bookmark" : "Dostop do obstoječega zaznamka je spodletel",
    "Failed to create bookmark" : "Ustvarjanje zaznamka je spodletelo",
    "Failed to save bookmark" : "Shranjevanje zaznamka je spodletelo",
    "Failed to move bookmark" : "Premikanje zaznamka je spodletelo",
    "Failed to delete bookmark" : "Brisanje zaznamka je spodletelo",
    "Failed to rename tag" : "Preimenovanje oznake je spodletelo",
    "Failed to load tags" : "Nalaganje oznak je spodletelo",
    "Failed to load folders" : "Nalaganje map je spodletelo",
    "Failed to delete folder" : "Brisanje mape je spodletelo",
    "Failed to create folder" : "Ustvarjanje mape je spodletelo",
    "Failed to fetch bookmarks." : "Pridobivanje zaznamkov je spodletelo",
    "Failed to change setting" : "Spreminjanje nastavitev je spodletelo",
    "Failed to load setting {key}" : "Nalaganje ključa nastavitve {key} je spodletelo",
    "Failed to update share {shareId}" : "Posodabljanje {shareId} je spodletelo",
    "Failed to delete share {shareId}" : "Brisanje {shareId} je spodletelo",
    "Bookmarks feed" : "Vir zaznamkov"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
